[−][src]Struct ethereum_keystore::keystore::KeyFile
A keystore file (account private core encrypted with a passphrase)
Fields
visible: Option<bool>Specifies if Keyfile is visible
name: Option<String>User specified name
description: Option<String>User specified description
address: AddressAddress
uuid: UuidUUID v4
crypto: CryptoTypeMethods
impl KeyFile[src]
pub fn decode(f: &str) -> Result<KeyFile, Error>[src]
Decode Keyfile from JSON
Handles different variants of crypto section
impl KeyFile[src]
pub fn new(
passphrase: &str,
sec_level: &KdfDepthLevel,
name: Option<String>,
description: Option<String>
) -> Result<KeyFile, Error>[src]
passphrase: &str,
sec_level: &KdfDepthLevel,
name: Option<String>,
description: Option<String>
) -> Result<KeyFile, Error>
Creates a new KeyFile with specified passphrase at random (rand::OsRng)
Arguments
passphrase- password for key derivation function
pub fn new_custom<R: Rng>(
pk: PrivateKey,
passphrase: &str,
kdf: Kdf,
rng: &mut R,
name: Option<String>,
description: Option<String>
) -> Result<KeyFile, Error>[src]
pk: PrivateKey,
passphrase: &str,
kdf: Kdf,
rng: &mut R,
name: Option<String>,
description: Option<String>
) -> Result<KeyFile, Error>
Creates a new KeyFile with specified PrivateKey, passphrase, key derivation function
and with given custom random generator
Arguments
pk- a private keypassphrase- password for key derivation functionkdf- customized key derivation functionrnd- predefined random number generator
pub fn decrypt_address(&self, password: &str) -> Result<Address, Error>[src]
Decrypt public address from keystore file by a password
pub fn decrypt_key(&self, passphrase: &str) -> Result<PrivateKey, Error>[src]
Decrypt private key from keystore file by a password
pub fn encrypt_key(&mut self, pk: PrivateKey, passphrase: &str)[src]
Encrypt a new private key for keystore file with a passphrase
pub fn encrypt_key_custom<R: Rng>(
&mut self,
pk: PrivateKey,
passphrase: &str,
rng: &mut R
)[src]
&mut self,
pk: PrivateKey,
passphrase: &str,
rng: &mut R
)
Encrypt a new private key for keystore file with a passphrase and with given custom random generator